// gofips is a package that, when imported, unsets the GOFIPS environment variable
// and stores it for later use.
//
// This is useful to support running commands like `GOFIPS=1 go test ./...` and
// `GOFIPS=1 go run .` with a Go toolchain not built with a FIPS-enabled crypto backend.
// In such cases, the user intends to pass the GOFIPS environment variable to the
// test or run sub-processes, not to the go command itself.
//
// This package needs to have a minimal dependency graph so that it is initialized
// before crypto/internal/backend, else it will have no effect.
package gofips

import "syscall"

var gofips string
var gofipsSet bool

const gofipsName = "GOFIPS"

func init() {
	if v, found := syscall.Getenv(gofipsName); found {
		gofips = gofipsName + "=" + v
		gofipsSet = true
		syscall.Unsetenv(gofipsName)
	}
}

// GOFIPS returns the GOFIPS environment variable at the time
// init was called, and whether it was set.
func GOFIPS() (string, bool) {
	return gofips, gofipsSet
}
